@@ -202,73 +202,87 @@ load_csv <- function(rv,
 
   # datatransformation source:
   for (i in keys_to_test) {
-    # get column names
-    col_names <- colnames(outlist[[i]])
 
-    # check, if column name in variables of interest
-    # var_names of interest:
-    var_names <- rv$mdr[get("source_table_name") == i &
-                          get("source_system_name") == system$system_name,
-    ][
-      , get("source_variable_name")
-    ]
-    stopifnot(is.character(var_names))
+    tryCatch(
+      expr = {
+        # get column names
+        col_names <- colnames(outlist[[i]])
 
-    # workaround to hide shiny-stuff, when going headless
-    msg <- paste("Transforming source variable types", i)
-    DIZtools::feedback(msg, logjs = isFALSE(headless), findme = "776ba03cbf",
-                       logfile_dir = rv$log$logfile_dir,
-                       headless = rv$headless)
-
-    for (j in col_names) {
-      var_type <- rv$mdr[get("source_system_name") == system$system_name &
-                           get("source_table_name") == i &
-                           get("source_variable_name") == j,
-                         unique(get("variable_type"))]
-
-      if (j %in% var_names && j %in% colnames(outlist[[i]])) {
-        vn <- rv$mdr[get("source_table_name") == i &
-                       get("source_system_name") == system$system_name,
+        # check, if column name in variables of interest
+        # var_names of interest:
+        var_names <- rv$mdr[get("source_table_name") == i &
+                              get("source_system_name") == system$system_name,
         ][
-          get("source_variable_name") ==
-            j, unique(get("variable_name"))]
-        colnames(outlist[[i]])[which(col_names == j)] <- vn
+          , get("source_variable_name")
+        ]
+        stopifnot(is.character(var_names))
 
-        if (var_type %in% c("enumerated", "string", "catalog")) {
-          # transform to factor
-          outlist[[i]][, (vn) := factor(get(vn))]
-        } else if (var_type == "datetime") {
-          # transform date variables
-          date_format <- rv$mdr[
-            get("source_system_name") == system$system_name &
-              get("source_table_name") == i &
-              get("variable_name") == vn,
-            unique(get("constraints"))
-          ]
-          if (is.na(date_format) ||
-              grepl("^\\s*$", date_format) ||
-              is.null(jsonlite::fromJSON(
-                date_format
-              )[["datetime"]][["format"]])) {
-            # set date format to default value
-            date_format <- "%Y-%m-%d"
-          } else {
-            date_format <- jsonlite::fromJSON(
-              date_format
-            )[["datetime"]][["format"]]
+        # workaround to hide shiny-stuff, when going headless
+        msg <- paste("Transforming source variable types", i)
+        DIZtools::feedback(msg, logjs = isFALSE(headless),
+                           findme = "776ba03cbf",
+                           logfile_dir = rv$log$logfile_dir,
+                           headless = rv$headless)
+
+        for (j in col_names) {
+          var_type <- rv$mdr[get("source_system_name") == system$system_name &
+                               get("source_table_name") == i &
+                               get("source_variable_name") == j,
+                             unique(get("variable_type"))]
+
+          if (j %in% var_names && j %in% colnames(outlist[[i]])) {
+            vn <- rv$mdr[get("source_table_name") == i &
+                           get("source_system_name") == system$system_name,
+            ][
+              get("source_variable_name") ==
+                j, unique(get("variable_name"))]
+            colnames(outlist[[i]])[which(col_names == j)] <- vn
+
+            if (var_type %in% c("enumerated", "string", "catalog")) {
+              # transform to factor
+              outlist[[i]][, (vn) := factor(get(vn))]
+            } else if (var_type == "datetime") {
+              # transform date variables
+              date_format <- rv$mdr[
+                get("source_system_name") == system$system_name &
+                  get("source_table_name") == i &
+                  get("variable_name") == vn,
+                unique(get("constraints"))
+              ]
+              if (is.na(date_format) ||
+                  grepl("^\\s*$", date_format) ||
+                  is.null(jsonlite::fromJSON(
+                    date_format
+                  )[["datetime"]][["format"]])) {
+                # set date format to default value
+                date_format <- "%Y-%m-%d"
+              } else {
+                date_format <- jsonlite::fromJSON(
+                  date_format
+                )[["datetime"]][["format"]]
+              }
+              outlist[[i]][, (vn) := as.Date(
+                as.character(get(vn)),
+                format = date_format
+              )]
+            } else if (var_type %in% c("integer", "float")) {
+              # transform numeric variables
+              outlist[[i]][, (vn) := as.numeric(
+                as.character(get(vn))
+              )]
+            }
           }
-          outlist[[i]][, (vn) := as.Date(
-            as.character(get(vn)),
-            format = date_format
-          )]
-        } else if (var_type %in% c("integer", "float")) {
-          # transform numeric variables
-          outlist[[i]][, (vn) := as.numeric(
-            as.character(get(vn))
-          )]
         }
+      }, error = function(e) {
+        DIZtools::feedback(
+          cat(e), logjs = isFALSE(headless),
+          type = "Error",
+          findme = "776bb03cbf",
+          logfile_dir = rv$log$logfile_dir,
+          headless = rv$headless
+        )
       }
-    }
+    )
   }
   return(outlist)
 }
@@ -318,12 +332,11 @@ load_database <- function(rv,
           ]
           replace_string <- paste0(
             "AS r_intermediate WHERE r_intermediate.",
-            restricting_date_var, " >= '",
+            restricting_date_var, " BETWEEN '",
             rv$restricting_date$start,
-            "' AND r_intermediate.",
-            restricting_date_var, " <= '",
+            "' AND '",
             rv$restricting_date$end,
-            "' "
+            "'"
           )
           sql <- gsub("AS r_intermediate", replace_string, sql_statements[[i]])
           msg <- paste0(msg, " (using a MODIFIED SUBSELECT)")
@@ -417,10 +430,14 @@ load_database <- function(rv,
         return(NULL)
       })
 
+      if (is.null(dat)) {
+        return(NULL)
+      }
+
 
       # check, if table has more than two columns and thus does not comply
       # with DQAstats table requirements for SQL based systems
-      if (is.null(dat) || ncol(dat) > 2) {
+      if (ncol(dat) > 2) {
         msg <- paste0(
           "Table of data element '",
           i,
@@ -457,6 +474,9 @@ load_database <- function(rv,
 
   DIZutils::close_connection(db_con)
 
+  # remove data elements for which the sql-statement failed
+  outlist <- outlist[!sapply(outlist, is.null)]
+
   for (i in keys_to_test) {
     # workaround to hide shiny-stuff, when going headless
     msg <- paste("Transforming target variable types", i)
@@ -733,11 +753,35 @@ data_loading <- function(rv, system, keys_to_test) {
     outlist$sql_statements <- NA
 
   } else if (system$system_type %in% c("oracle", "postgres")) {
+
+    # import target SQL
+    msg <- "Loaded SQL statements from "
+    if (is.null(rv$sql_statements)) {
+      sql_statements <- load_sqls(
+        utils_path = rv$utilspath,
+        db = system$system_name
+      )
+      DIZtools::feedback(
+        print_this = paste0(msg, "file."),
+        logjs = isFALSE(rv$headless),
+        findme = "73c0ddd8d4",
+        logfile_dir = rv$log$logfile_dir,
+        headless = rv$headless
+      )
+    } else {
+      sql_statements <- rv$sql_statements[[system$system_name]]
+      DIZtools::feedback(
+        print_this = paste0(
+          "SQL statements already present. ", msg, "elsewhere."
+        ),
+        logjs = isFALSE(rv$headless),
+        findme = "73c0fff8d4",
+        logfile_dir = rv$log$logfile_dir,
+        headless = rv$headless
+      )
+    }
+
     if (system$system_type == "postgres") {
-      # import target SQL
-      sql_statements <- load_sqls(utils_path = rv$utilspath,
-                                          db = system$system_name)
-      stopifnot(is.list(sql_statements))
 
       # test target_db
       if (is.null(system$settings)) {
@@ -764,10 +808,6 @@ data_loading <- function(rv, system, keys_to_test) {
       stopifnot(!is.null(db_con))
 
     }  else if (system$system_type == "oracle") {
-      # import target SQL
-      sql_statements <- load_sqls(utils_path = rv$utilspath,
-                                          db = system$system_name)
-      stopifnot(is.list(sql_statements))
 
       # test target_db
       if (is.null(system$settings)) {
